import { Construct } from "constructs";
export interface ParameterProps {
    /**
     * Value of the parameter
     */
    value: string;
}
/**
 * The `Parameter` construct is a higher level CDK construct that makes it easy to manage app environment variables.
 *
 * @example
 * ### Using the minimal config
 *
 * ```js
 * import { Config } from "@serverless-stack/resources";
 *
 * new Config.Parameter(stack, "TABLE_NAME", table.tableName);
 * ```
 */
export declare class Parameter extends Construct {
    readonly name: string;
    readonly value: string;
    private static all;
    constructor(scope: Construct, id: string, props: ParameterProps);
    /** @internal */
    static getAllNames(): string[];
    /** @internal */
    static hasName(name: string): boolean;
    /** @internal */
    static clear(): void;
    /** @internal */
    getConstructMetadata(): {
        type: "Parameter";
        data: {
            name: string;
        };
    };
    static create<T extends Record<string, any>>(scope: Construct, parameters: T): { [key in keyof T]: Parameter; };
}
